summaryrefslogtreecommitdiff
path: root/cui/source/customize
diff options
context:
space:
mode:
Diffstat (limited to 'cui/source/customize')
-rw-r--r--cui/source/customize/acccfg.cxx3
-rw-r--r--cui/source/customize/cfg.cxx10
-rw-r--r--cui/source/customize/cfgutil.cxx5
-rw-r--r--cui/source/customize/eventdlg.cxx3
-rw-r--r--cui/source/customize/macropg.cxx2
-rw-r--r--cui/source/customize/selector.cxx4
6 files changed, 5 insertions, 22 deletions
diff --git a/cui/source/customize/acccfg.cxx b/cui/source/customize/acccfg.cxx
index b2a58dd84b90..13d5bff7e580 100644
--- a/cui/source/customize/acccfg.cxx
+++ b/cui/source/customize/acccfg.cxx
@@ -26,9 +26,6 @@
*
************************************************************************/
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
//-----------------------------------------------
// include own files
diff --git a/cui/source/customize/cfgutil.cxx b/cui/source/customize/cfgutil.cxx
index 86eed6d9ce8b..18f1fa122562 100644
--- a/cui/source/customize/cfgutil.cxx
+++ b/cui/source/customize/cfgutil.cxx
@@ -26,9 +26,6 @@
*
************************************************************************/
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
#include "cfgutil.hxx"
#include <com/sun/star/beans/XPropertySet.hpp>
@@ -1513,7 +1510,7 @@ void SfxConfigGroupListBox_Impl::RequestingChilds( SvLBoxEntry *pEntry )
}
default:
- DBG_ERROR( "Falscher Gruppentyp!" );
+ OSL_FAIL( "Falscher Gruppentyp!" );
break;
}
}
diff --git a/cui/source/customize/eventdlg.cxx b/cui/source/customize/eventdlg.cxx
index 85c2d44a6a64..02383fc0b3bf 100644
--- a/cui/source/customize/eventdlg.cxx
+++ b/cui/source/customize/eventdlg.cxx
@@ -26,9 +26,6 @@
*
************************************************************************/
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
// include ***************************************************************
#include <svtools/svmedit.hxx>
#include <tools/diagnose_ex.h>
diff --git a/cui/source/customize/macropg.cxx b/cui/source/customize/macropg.cxx
index 4498c5ea4ccb..3f26f09d9761 100644
--- a/cui/source/customize/macropg.cxx
+++ b/cui/source/customize/macropg.cxx
@@ -26,8 +26,6 @@
*
************************************************************************/
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
#include <basic/basmgr.hxx>
#include "macropg.hxx"
diff --git a/cui/source/customize/selector.cxx b/cui/source/customize/selector.cxx
index 28a3d42cb35e..6fee34f67ca6 100644
--- a/cui/source/customize/selector.cxx
+++ b/cui/source/customize/selector.cxx
@@ -26,8 +26,6 @@
*
************************************************************************/
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
#include <vcl/help.hxx>
#include <vcl/msgbox.hxx>
#include <vcl/metric.hxx>
@@ -955,7 +953,7 @@ void SvxConfigGroupListBox_Impl::RequestingChilds( SvLBoxEntry *pEntry )
}
default:
- DBG_ERROR( "Falscher Gruppentyp!" );
+ OSL_FAIL( "Falscher Gruppentyp!" );
break;
}
}
diff --git a/cui/source/customize/cfg.cxx b/cui/source/customize/cfg.cxx
index 14087c3c5659..99cb2445acc7 100644
--- a/cui/source/customize/cfg.cxx
+++ b/cui/source/customize/cfg.cxx
@@ -26,9 +26,6 @@
*
************************************************************************/
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
#include <stdlib.h>
#include <time.h>
@@ -4141,7 +4138,7 @@ bool EntrySort( SvxConfigEntry* a, SvxConfigEntry* b )
SvxEntries* ToolbarSaveInData::GetEntries()
{
- typedef ::std::hash_map< ::rtl::OUString,
+ typedef ::boost::unordered_map< ::rtl::OUString,
bool,
::rtl::OUStringHash,
::std::equal_to< ::rtl::OUString > > ToolbarInfo;
@@ -4202,7 +4199,7 @@ SvxEntries* ToolbarSaveInData::GetEntries()
pEntry->SetStyle( GetSystemStyle( url ) );
// insert into hash_map to filter duplicates from the parent
aToolbarInfo.insert( ToolbarInfo::value_type( systemname, true ));
OUString custom(RTL_CONSTASCII_USTRINGPARAM(CUSTOM_TOOLBAR_STR));
@@ -5290,7 +5287,7 @@ SvxIconSelectorDialog::SvxIconSelectorDialog( Window *pWindow,
{
FreeResource();
- typedef ::std::hash_map< ::rtl::OUString,
+ typedef ::boost::unordered_map< ::rtl::OUString,
bool,
::rtl::OUStringHash,
::std::equal_to< ::rtl::OUString > > ImageInfo;
@@ -5975,7 +5972,6 @@ BitmapEx SvxIconSelectorDialog::AutoScaleBitmap(BitmapEx & aBitmap, const long a
imgposY = (aStandardSize - imgOldHeight) / 2 + 0.5;
}
- Size aBmpSize = aRet.GetSizePixel();
Size aStdSize( aStandardSize, aStandardSize );
Rectangle aRect(aEmptyPoint, aStdSize );
@@ -4202,7 +4199,7 @@ SvxEntries* ToolbarSaveInData::GetEntries()
pEntry->SetStyle( GetSystemStyle( url ) );
- // insert into hash_map to filter duplicates from the parent
+ // insert into boost::unordered_map to filter duplicates from the parent
aToolbarInfo.insert( ToolbarInfo::value_type( systemname, true ));
OUString custom(RTL_CONSTASCII_USTRINGPARAM(CUSTOM_TOOLBAR_STR));